==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/containerservice/kotlin/enums/OpenShiftContainerServiceVMSize.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerservice.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * Size of agent VMs.
 */
public enum class OpenShiftContainerServiceVMSize(
    public val javaValue:
    com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize,
) : ConvertibleToJava<com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize> {
    Standard_D2s_v3(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_D2s_v3),
    Standard_D4s_v3(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_D4s_v3),
    Standard_D8s_v3(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_D8s_v3),
    Standard_D16s_v3(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_D16s_v3),
    Standard_D32s_v3(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_D32s_v3),
    Standard_D64s_v3(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_D64s_v3),
    Standard_DS4_v2(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_DS4_v2),
    Standard_DS5_v2(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_DS5_v2),
    Standard_F8s_v2(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_F8s_v2),
    Standard_F16s_v2(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_F16s_v2),
    Standard_F32s_v2(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_F32s_v2),
    Standard_F64s_v2(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_F64s_v2),
    Standard_F72s_v2(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_F72s_v2),
    Standard_F8s(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_F8s),
    Standard_F16s(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_F16s),
    Standard_E4s_v3(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_E4s_v3),
    Standard_E8s_v3(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_E8s_v3),
    Standard_E16s_v3(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_E16s_v3),
    Standard_E20s_v3(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_E20s_v3),
    Standard_E32s_v3(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_E32s_v3),
    Standard_E64s_v3(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_E64s_v3),
    Standard_GS2(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_GS2),
    Standard_GS3(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_GS3),
    Standard_GS4(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_GS4),
    Standard_GS5(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_GS5),
    Standard_DS12_v2(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_DS12_v2),
    Standard_DS13_v2(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_DS13_v2),
    Standard_DS14_v2(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_DS14_v2),
    Standard_DS15_v2(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_DS15_v2),
    Standard_L4s(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_L4s),
    Standard_L8s(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_L8s),
    Standard_L16s(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_L16s),
    Standard_L32s(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_L32s),
    ;

    override fun toJava():
        com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize = javaValue

    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize):
            OpenShiftContainerServiceVMSize =
            OpenShiftContainerServiceVMSize.values().first { it.javaValue == javaType }
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/containerservice/kotlin/enums/OpenShiftContainerServiceVMSize.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerservice.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * Size of agent VMs.
 */
public enum class OpenShiftContainerServiceVMSize(
    public val javaValue: com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize,
) : ConvertibleToJava<com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize> {
    Standard_D2s_v3(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_D2s_v3),
    Standard_D4s_v3(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_D4s_v3),
    Standard_D8s_v3(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_D8s_v3),
    Standard_D16s_v3(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_D16s_v3),
    Standard_D32s_v3(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_D32s_v3),
    Standard_D64s_v3(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_D64s_v3),
    Standard_DS4_v2(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_DS4_v2),
    Standard_DS5_v2(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_DS5_v2),
    Standard_F8s_v2(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_F8s_v2),
    Standard_F16s_v2(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_F16s_v2),
    Standard_F32s_v2(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_F32s_v2),
    Standard_F64s_v2(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_F64s_v2),
    Standard_F72s_v2(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_F72s_v2),
    Standard_F8s(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_F8s),
    Standard_F16s(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_F16s),
    Standard_E4s_v3(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_E4s_v3),
    Standard_E8s_v3(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_E8s_v3),
    Standard_E16s_v3(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_E16s_v3),
    Standard_E20s_v3(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_E20s_v3),
    Standard_E32s_v3(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_E32s_v3),
    Standard_E64s_v3(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_E64s_v3),
    Standard_GS2(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_GS2),
    Standard_GS3(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_GS3),
    Standard_GS4(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_GS4),
    Standard_GS5(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_GS5),
    Standard_DS12_v2(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_DS12_v2),
    Standard_DS13_v2(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_DS13_v2),
    Standard_DS14_v2(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_DS14_v2),
    Standard_DS15_v2(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_DS15_v2),
    Standard_L4s(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_L4s),
    Standard_L8s(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_L8s),
    Standard_L16s(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_L16s),
    Standard_L32s(com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize.Standard_L32s),
    ;

    override fun toJava(): com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize = javaValue

    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.containerservice.enums.OpenShiftContainerServiceVMSize): OpenShiftContainerServiceVMSize =
            OpenShiftContainerServiceVMSize.values().first { it.javaValue == javaType }
    }
}
